@@ -50,9 +50,10 @@ class Postgres(Dialect):
 
 
 class Presto(Dialect):
-    def _approx_distinct_sql(gen, e):
-        accuracy = ', ' + gen.sql(e, 'accuracy') if e.args.get('accuracy') else ''
-        return f"APPROX_DISTINCT({gen.sql(e, 'this')}{accuracy})"
+    def _approx_distinct_sql(self, expression):
+        accuracy = expression.args.get('accuracy')
+        accuracy = ', ' + self.sql(accuracy) if accuracy else ''
+        return f"APPROX_DISTINCT({self.sql(expression, 'this')}{accuracy})"
 
     def _parse_approx_distinct(args):
         return exp.ApproxDistinct(
@@ -60,25 +61,47 @@ class Presto(Dialect):
             accuracy=args[1] if len(args) > 1 else None,
         )
 
+    def _create_sql(self, expression):
+        table_sql = self.sql(expression, 'table')
+        this_sql = self.sql(expression, 'this')
+        exists_sql = ' IF NOT EXISTS ' if expression.args.get('exists') else ' '
+        file_format = self.sql(expression.args.get('file_format')).replace(self.quote, '')
+        file_format = f" WITH (FORMAT = '{file_format}') " if file_format else ' '
+        return f"CREATE TABLE{exists_sql}{table_sql}{file_format}AS{self.sep()}{this_sql}"
+
     transforms = {
         TokenType.INT: 'INTEGER',
         TokenType.FLOAT: 'REAL',
         TokenType.BINARY: 'VARBINARY',
         exp.ApproxDistinct: _approx_distinct_sql,
+        exp.Create: _create_sql,
     }
 
     functions = {
         'APPROX_DISTINCT': _parse_approx_distinct,
     }
 
-class Spark(Dialect):
-    def _approx_distinct_sql(gen, e):
-        if e.args.get('accuracy'):
-            gen.unsupported('APPROX_COUNT_DISTINCT does not support accuracy')
-        return f"APPROX_COUNT_DISTINCT({gen.sql(e, 'this')})"
+
+class Hive(Dialect):
+    identifier = '`'
+
+    def _approx_distinct_sql(self, expression):
+        if expression.args.get('accuracy'):
+            self.unsupported('APPROX_COUNT_DISTINCT does not support accuracy')
+        return f"APPROX_COUNT_DISTINCT({self.sql(expression, 'this')})"
 
     transforms = {
         exp.ApproxDistinct: _approx_distinct_sql,
+    }
+
+    functions = {
+        'APPROX_COUNT_DISTINCT': lambda args: exp.ApproxDistinct(this=args[0]),
+    }
+
+
+class Spark(Hive):
+    transforms = {
+        **Hive.transforms,
         TokenType.TINYINT: 'BYTE',
         TokenType.SMALLINT: 'SHORT',
         TokenType.BIGINT: 'BIGINT',
@@ -88,12 +111,6 @@ class Spark(Dialect):
         TokenType.BINARY: 'ARRAY[BYTE]',
     }
 
-    functions = {
-        'APPROX_COUNT_DISTINCT': lambda args: exp.ApproxDistinct(this=args[0]),
-    }
-
-    identifier = '`'
-
 
 class SQLite(Dialect):
     transforms = {
