@@ -65,32 +65,41 @@ class TokenType(AutoName):
     CASE = auto()
     CAST = auto()
     COUNT = auto()
+    CREATE = auto()
     CROSS = auto()
     DESC = auto()
     DISTINCT = auto()
     ELSE = auto()
     END = auto()
+    EXISTS = auto()
+    FORMAT = auto()
     FULL = auto()
     FUNC = auto()
     FROM = auto()
     GROUP = auto()
     HAVING = auto()
+    IF = auto()
     IN = auto()
     INNER = auto()
     IS = auto()
     JOIN = auto()
+    LATERAL = auto()
     LEFT = auto()
     MAP = auto()
     NULL = auto()
     ON = auto()
     ORDER = auto()
+    ORDINALITY = auto()
     OUTER = auto()
     OVER = auto()
     PARTITION = auto()
     SELECT = auto()
+    STORED = auto()
     RIGHT = auto()
     THEN = auto()
     UNION = auto()
+    UNNEST = auto()
+    VIEW = auto()
     WHEN = auto()
     WHERE = auto()
     WITH = auto()
@@ -102,6 +111,7 @@ class Token:
         self.text = text
         self.line = line
         self.col = col - len(text)
+        self.parent = None
 
     def __repr__(self):
         attributes = ", ".join([f"{k}: {v}" for k, v in self.__dict__.items()])
@@ -140,19 +150,24 @@ class Tokenizer:
         'CASE': TokenType.CASE,
         'CAST': TokenType.CAST,
         'COUNT': TokenType.COUNT,
+        'CREATE': TokenType.CREATE,
         'CROSS': TokenType.CROSS,
         'DESC': TokenType.DESC,
         'DISTINCT': TokenType.DISTINCT,
         'ELSE': TokenType.ELSE,
         'END': TokenType.END,
+        'EXISTS': TokenType.EXISTS,
+        'FORMAT': TokenType.FORMAT,
         'FULL': TokenType.FULL,
         'FROM': TokenType.FROM,
         'GROUP': TokenType.GROUP,
         'HAVING': TokenType.HAVING,
+        'IF': TokenType.IF,
         'IN': TokenType.IN,
         'INNER': TokenType.INNER,
         'IS': TokenType.IS,
         'JOIN': TokenType.JOIN,
+        'LATERAL': TokenType.LATERAL,
         'LEFT': TokenType.LEFT,
         'NOT': TokenType.NOT,
         'NULL': TokenType.NULL,
@@ -164,8 +179,12 @@ class Tokenizer:
         'PARTITION': TokenType.PARTITION,
         'RIGHT': TokenType.RIGHT,
         'SELECT': TokenType.SELECT,
+        'STORED': TokenType.STORED,
+        'TABLE': TokenType.TABLE,
         'THEN': TokenType.THEN,
         'UNION': TokenType.UNION,
+        'UNNEST': TokenType.UNNEST,
+        'VIEW': TokenType.VIEW,
         'WHEN': TokenType.WHEN,
         'WHERE': TokenType.WHERE,
         'WITH': TokenType.WITH,
